@@ -43,16 +43,26 @@ sub GetGitLastCommitDate {
 }
 
 ################################################################
-## Return the path of a program.
-##
-## The function successively checks if the program exists in various
-## directories: 
-## 1)  $ENV{RSAT_BIN} (defined in RSAT_config.props)
-## 2)  $ENV{RSAT}/bin
-## 3) in the user path
-##
-## Usage:
-##    my $program_path = &RSAT::server::GetProgramPath("program_name", $die_on_error, @preferred_paths);
+=pod
+
+=item GetProgramPath
+
+Return the path of a program.
+
+The function successively checks if the program exists in various
+directories: 
+
+1) $ENV{RSAT_BIN} (defined in RSAT_config.props)
+2) $ENV{RSAT}/bin
+3) In the subcommands supported by the rsat command
+4) In the perl-scripts and python-scripts subdirectories of RSAT 
+5) Anywhere in the user path
+
+Usage:
+    my $program_path = &RSAT::server::GetProgramPath("program_name", $die_on_error, @preferred_paths);
+
+=cut
+
 sub GetProgramPath {
   my ($program_name, $die_on_error, @preferred_paths) = @_;
   my $program_path = "";
@@ -81,7 +91,24 @@ sub GetProgramPath {
     }
   }
 
-  ## If the path has ont ben found yet, find the program anywhere in
+  ## Test if the command is known as rsat subcommand
+  my @subcommands = `rsat --list`;
+  my %rsat_cmd = ();
+  foreach my $cmd (@subcommands) {
+      $cmd = &RSAT::util::trim($cmd);
+      $rsat_cmd{$cmd} = $cmd;
+      $rsat_cmd_lc{lc($cmd)} = $cmd;
+  }
+  my @rsat_cmd = sort(keys(%rsat_cmd));
+  my @rsat_cmd_lc = sort(keys(%rsat_cmd_lc));
+  if (defined($rsat_cmd{$program_name})) {
+#      &RSAT::message::Debug("GetProgramPath()", "rsat subcommand", "rsat ".$program_name) if ($main::verbose >= 5);
+      return("rsat ".$program_name);
+  }
+  
+  #   die "rsat subcommands:\n\t", join("\n\t", @rsat_cmd), "\n";
+  
+  ## If the path has not ben found yet, find the program anywhere in
   ## the user path
   unless ($program_path) {
       $program_path = `which $program_name`;
@@ -451,7 +478,7 @@ sub ReadProperties {
     unless (-e $property_file) {
       &RSAT::message::Warning("This RSAT site is not properly configured.\n",
 			      '$ENV{RSAT}='.$ENV{RSAT},
-			      "\n\tPoperty file does not exist: ".$property_file,
+			      "\n\tProperty file does not exist: ".$property_file,
 			      "\n\tPlease contact the system administrator ".$ENV{SERVER_ADMIN});
       $property_file = $`."../RSAT_config_default.props"; #`
       $default_props = 1;
@@ -681,15 +708,39 @@ sub supported_motif_databases {
   return %matrix_db;
 }
 
-################################################################
-## The initialization is performed in the main scope, because this si
-## the place where most RSAT programs expect to find the global
-## variables, due to the initial organization of RSAT.
-##
-## This should be changed at some point, by having server-specific
-## variables attached to the RSAT::server class.
+sub supported_motif_databases_2 {
+    our  %matrix_db = ();
+    ## Load the file containing the path to the databases
+    my $mat_db = $ENV{RSAT}."/public_html/motif_databases/db_matrix_files.tab" ;
+    unless (-e $mat_db) {
+        &RSAT::message::Warning( "Motif database description file not found ($mat_db)");
+        return;
+    }
+    open MAT_DB, "<$mat_db" or &RSAT::message::Warning( "Cannot read motif database description file ($mat_db)");;
+    while (my $line = <MAT_DB>) {
+        chomp($line);
+        next if ($line =~ /^;/); ## Skip comment lines
+        next if ($line =~ /^";/); ## Skip comment lines
+        next if ($line =~ /^#/); ## Skip header line
+        next unless ($line =~ /\S/); ## Skip empty lines
+        chomp($line);
+        $line =~ s/\r//;
+        my ($name, $format, $file, $descr, $version, $url, $category, $db_name) = split (/\t/,$line);        
+        if(! defined $matrix_db{$db_name}){ $matrix_db{$db_name} = (); }
+        my %db_info = ();
+        $db_info{'name'} = $name || "";
+        $db_info{'format'} = $format || "";
+        $db_info{'file'} = $file;
+        $db_info{'descr'} = $descr || $name;
+        $db_info{'version'} = $version || "";
+        $db_info{'url'} = $url || "";
+        $db_info{'category'} = $category || "";
+        
+        $matrix_db{$db_name}{$name} = \%db_info;        
+    }
+    
+    return %matrix_db;
+}
 
-## OBSOLETE ? (JvH 2014-05-03)
-# package main;
 
 return(1);
